@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from uuid import UUID
+from ujson import loads
 
 from tornado.web import RequestHandler
 from tornado import gen
@@ -16,6 +17,7 @@ class CreateFactHandler(RequestHandler):
         key = self.get_argument('key')
         unit = self.get_argument('unit', None)
         value = self.get_argument('value')
+        title = self.get_argument('title')
 
         parsed_uuid = None
         try:
@@ -32,7 +34,10 @@ class CreateFactHandler(RequestHandler):
             self.finish()
             return
 
-        review.add_fact(key=key, unit=unit, value=value)
+        if unit and unit == 'values':
+            value = loads(value)
+
+        review.add_fact(key=key, unit=unit, value=value, title=title)
         yield review.save()
 
         self.write('OK')
