@@ -6,7 +6,9 @@ from cow.plugins.motorengine_plugin import MotorEnginePlugin
 
 from holmes.handlers.worker import WorkerHandler, WorkersHandler
 from holmes.handlers.worker_state import WorkerStateHandler
-from holmes.handlers.page import PageHandler, PagesHandler
+from holmes.handlers.page import (
+    PageHandler, PagesHandler, PageReviewsHandler, PageViolationsPerDayHandler
+)
 from holmes.handlers.fact import CreateFactHandler
 from holmes.handlers.violation import (
     CreateViolationHandler, MostCommonViolationsHandler
@@ -28,12 +30,14 @@ class HolmesApiServer(Server):
         handlers = [
             (r'/most-common-violations/?', MostCommonViolationsHandler),
             (r'/workers/?', WorkersHandler),
-            (r'/worker/([a-z0-9-]*)/ping/?', WorkerHandler),
+            (r'/worker/([a-z0-9-]*)/(alive|dead)/?', WorkerHandler),
             (r'/worker/([a-z0-9-]*)/review/([a-z0-9-]*)/(start|complete)', WorkerStateHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/complete/?', CompleteReviewHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/fact/?', CreateFactHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/violation/?', CreateViolationHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/?', ReviewHandler),
+            (r'/page/([a-z0-9-]*)/reviews/?', PageReviewsHandler),
+            (r'/page/([a-z0-9-]*)/violations-per-day/?', PageViolationsPerDayHandler),
             (r'/page/([a-z0-9-]*)/?', PageHandler),
             (r'/page/?', PageHandler),
             (r'/pages/?', PagesHandler),
