@@ -2,53 +2,50 @@
 # -*- coding: utf-8 -*-
 
 import sys
-import time
 import logging
-
-from ujson import dumps
 from uuid import uuid4
 from os.path import abspath, dirname, join
-from ujson import loads
 
 import requests
+from ujson import dumps, loads
 from requests.exceptions import ConnectionError
-from derpconf.config import verify_config
-from optparse import OptionParser
+from sheep import Shepherd
+from colorama import Fore, Style
 
+from holmes import __version__
 from holmes.config import Config
 from holmes.reviewer import Reviewer, InvalidReviewError
 
 
-class HolmesWorker(object):
+class HolmesWorker(Shepherd):
+    def __init__(self, *args, **kw):
+        super(HolmesWorker, self).__init__(*args, **kw)
 
-    def __init__(self, arguments=[]):
         self.root_path = abspath(join(dirname(__file__), '..'))
-
         self.uuid = uuid4().hex
-
         self.working = True
-        self.config = None
-
-        self._parse_opt(arguments)
-        self._load_config(self.options.verbose == 3)
-        self._config_logging()
 
         self.validators = self._load_validators()
 
-    def run(self):
-        try:
-            while self.working:
-                self._do_work()
-                logging.debug('Nap time (%ss)' % self.config.WORKER_SLEEP_TIME)
-                time.sleep(self.config.WORKER_SLEEP_TIME)
-        except KeyboardInterrupt:
-            logging.info('Bye.')
-            self.working = False
+    def get_description(self):
+        return "%s%sholmes-worker%s (holmes-api v%s)" % (
+            Fore.BLUE,
+            Style.BRIGHT,
+            Style.RESET_ALL,
+            __version__
+        )
+
+    def get_config_class(self):
+        return Config
 
     def stop_work(self):
+        try:
+            requests.post('%s/worker/%s/dead' % (self.config.HOLMES_API_URL, self.uuid), data={'worker_uuid': self.uuid})
+        except ConnectionError:
+            pass
         self.working = False
 
-    def _do_work(self):
+    def do_work(self):
         if self._ping_api():
             err = None
             job = self._load_next_job()
@@ -77,38 +74,13 @@ class HolmesWorker(object):
 
             reviewer.review()
 
-    def _load_validators(self, validators=None, validators_to_load=None):
-        if validators_to_load is None:
-            validators_to_load = self.config.VALIDATORS
-
-        if validators is None:
-            validators = []
-
-        for validator_full_name in validators_to_load:
-            if isinstance(validator_full_name, (tuple, set, list)):
-                self._load_validators(validators, validator_full_name)
-                continue
-
-            try:
-                module_name, class_name = validator_full_name.rsplit('.', 1)
-                module = __import__(module_name, globals(), locals(), class_name)
-                validators.append(getattr(module, class_name))
-            except ValueError:
-                logging.warn('Invalid validator name [%s]. Will be ignored.' % validator_full_name)
-            except AttributeError:
-                logging.warn('Validator [%s] not found. Will be ignored.' % validator_full_name)
-            except ImportError:
-                logging.warn('Module [%s] not found. Will be ignored.' % validator_full_name)
-
-        return validators
-
     def _ping_api(self):
         try:
-            requests.post('%s/worker/%s/ping' % (self.config.HOLMES_API_URL, self.uuid), data={'worker_uuid': self.uuid})
+            requests.post('%s/worker/%s/alive' % (self.config.HOLMES_API_URL, self.uuid), data={'worker_uuid': self.uuid})
             return True
         except ConnectionError:
             logging.fatal('Fail to ping API [%s]. Stopping Worker.' % self.config.HOLMES_API_URL)
-            self.working = False
+            self.stop_work()
             return False
 
     def _load_next_job(self):
@@ -118,7 +90,7 @@ class HolmesWorker(object):
                 return loads(response.text)
         except ConnectionError:
             logging.fatal('Fail to get next review from [%s]. Stopping Worker.' % self.config.HOLMES_API_URL)
-            self.working = False
+            self.stop_work()
 
     def _start_job(self, review_uuid):
         if not review_uuid:
@@ -144,40 +116,30 @@ class HolmesWorker(object):
         except ConnectionError:
             logging.error('Fail to complete worker.')
 
-    def _parse_opt(self, arguments):
-        parser = OptionParser()
-        parser.add_option('-c', '--conf', dest='conf', default=join(self.root_path, 'holmes/config/local.conf'),
-                          help='Configuration file to use for the server.')
-        parser.add_option('--verbose', '-v', action='count', default=0,
-                          help='Log level: v=warning, vv=info, vvv=debug.')
+    def _load_validators(self, validators=None, validators_to_load=None):
+        if validators_to_load is None:
+            validators_to_load = self.config.VALIDATORS
 
-        self.options, self.arguments = parser.parse_args(arguments)
+        if validators is None:
+            validators = []
 
-    def _load_config(self, verify=False):
-        if verify:
-            verify_config(self.options.conf)
-        self.config = Config.load(self.options.conf)
+        for validator_full_name in validators_to_load:
+            if isinstance(validator_full_name, (tuple, set, list)):
+                self._load_validators(validators, validator_full_name)
+                continue
 
-    def _config_logging(self):
-        LOGS = {
-            0: 'error',
-            1: 'warning',
-            2: 'info',
-            3: 'debug'
-        }
+            try:
+                module_name, class_name = validator_full_name.rsplit('.', 1)
+                module = __import__(module_name, globals(), locals(), class_name)
+                validators.append(getattr(module, class_name))
+            except ValueError:
+                logging.warn('Invalid validator name [%s]. Will be ignored.' % validator_full_name)
+            except AttributeError:
+                logging.warn('Validator [%s] not found. Will be ignored.' % validator_full_name)
+            except ImportError:
+                logging.warn('Module [%s] not found. Will be ignored.' % validator_full_name)
 
-        if self.options.verbose:
-            log_level = LOGS[self.options.verbose].upper()
-        else:
-            log_level = self.config.LOG_LEVEL.upper()
-
-        logging.basicConfig(
-            level=log_level,
-            format=self.config.LOG_FORMAT,
-            datefmt=self.config.LOG_DATE_FORMAT
-        )
-
-        return log_level
+        return validators
 
 
 def main():
